@@ -1,4 +1,4 @@
-/*	$calcurse: calcurse.c,v 1.65 2008/08/10 09:24:46 culot Exp $	*/
+/*	$calcurse: calcurse.c,v 1.68 2008/09/21 08:06:43 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
@@ -379,9 +379,16 @@ main (int argc, char **argv)
 
 	case 'S':
 	case 's':		/* Save function */
-	  io_save_cal (&conf);
+	  io_save_cal (IO_MODE_INTERACTIVE, &conf);
 	  break;
 
+        case 'I':
+        case 'i':               /* Import function */
+          erase_status_bar ();
+          io_import_data (IO_MODE_INTERACTIVE, IO_IMPORT_ICAL, &conf, NULL);
+          do_storage = true;
+          break;
+          
 	case 'X':
 	case 'x':		/* Export function */
           erase_status_bar ();
@@ -392,11 +399,11 @@ main (int argc, char **argv)
 		{
 		case 'I':
 		case 'i':
-                  io_export_data (IO_EXPORT_INTERACTIVE, IO_EXPORT_ICAL, &conf);
+                  io_export_data (IO_MODE_INTERACTIVE, IO_EXPORT_ICAL, &conf);
 		  break;
 		case 'P':
 		case 'p':
-                  io_export_data (IO_EXPORT_INTERACTIVE, IO_EXPORT_PCAL, &conf);
+                  io_export_data (IO_MODE_INTERACTIVE, IO_EXPORT_PCAL, &conf);
 		  break;
 		}
 	      wins_reset ();
@@ -506,7 +513,7 @@ main (int argc, char **argv)
 	case ('Q'):		/* Quit calcurse :( */
 	case ('q'):
 	  if (conf.auto_save)
-	    io_save_cal (&conf);
+	    io_save_cal (IO_MODE_INTERACTIVE, &conf);
 
 	  if (conf.confirm_quit)
 	    {
