@@ -1,4 +1,4 @@
-/*	$calcurse: utils.c,v 1.48 2008/08/11 18:08:45 culot Exp $	*/
+/*	$calcurse: utils.c,v 1.52 2008/09/23 17:31:57 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
@@ -48,6 +48,7 @@ exit_calcurse (int status)
   clear ();
   refresh ();
   endwin ();
+  ui_mode = UI_CMDLINE;
   calendar_stop_date_thread ();
   exit (status);
 }
@@ -95,6 +96,29 @@ aerror (const char *file, int line, const char *assertion)
   ierror (errmsg, IERROR_FATAL);
 }
 
+void
+warnbox (const char *msg)
+{
+  const int WINCOL = col - 2;
+  const int WINROW = 10;
+  const int MSGLEN = WINCOL - 2;
+  WINDOW *warnwin;
+  char displmsg[MSGLEN];
+  
+  if (msg == NULL)
+    return;
+  strncpy (displmsg, msg, MSGLEN);
+  warnwin = popup (WINROW, WINCOL, (row - WINROW) / 2, (col - WINCOL) / 2,
+                   "/!\\");
+  custom_apply_attr (warnwin, ATTR_HIGHEST);
+  mvwprintw (warnwin, 5, (WINCOL - strlen (displmsg)) / 2, "%s", displmsg);
+  custom_remove_attr (warnwin, ATTR_HIGHEST);
+  wrefresh (warnwin);
+  wgetch (warnwin);
+  delwin (warnwin);
+  doupdate ();
+}
+
 /* 
  * Print a message in the status bar.
  * Message texts for first line and second line are to be provided.
@@ -421,6 +445,7 @@ status_bar (void)
   binding_t quit = { "  Q", _("Quit") };
   binding_t save = { "  S", _("Save") };
   binding_t export = { "  X", _("Export") };
+  binding_t import = { "  I", _("Import") };  
   binding_t add = { "  A", _("Add Item") };
   binding_t del = { "  D", _("Del Item") };
   binding_t edit = { "  E", _("Edit Itm") };
@@ -448,16 +473,16 @@ status_bar (void)
 
   binding_t *binding[TOTAL_CMDS] = {
     /* calendar keys */
-    &help, &quit, &save, &export, &day, &week, &weekb, &weeke, &tab,
-    &togo, &conf, &othr, &appt, &todo, &eday, &ewek, &draw, &today, &othr,
+    &help, &quit, &save, &tab, &import, &export, &day, &week, &weekb, &weeke,
+    &togo, &othr, &conf, &draw, &appt, &todo, &eday, &ewek, &today, &othr,
     /* appointment keys */
-    &help, &quit, &save, &export, &add, &del, &edit, &view, &rept,
-    &updn, &flag, &othr, &enote, &vnote, &appt, &todo, &eday, &ewek,
-    &conf, &togo, &tab, &draw, &today, &othr,
+    &help, &quit, &save, &tab, &import, &export, &add, &del, &edit, &view,
+    &rept, &othr, &updn, &flag, &enote, &vnote, &appt, &todo, &eday, &ewek,
+    &conf, &togo, &draw, &othr, &today, &othr,
     /* todo keys */
-    &help, &quit, &save, &export, &add, &del, &edit, &view, &prio,
-    &updn, &tab, &othr, &enote, &vnote, &appt, &todo, &eday, &ewek,
-    &conf, &togo, &draw, &today, &othr
+    &help, &quit, &save, &tab, &import, &export, &add, &del, &edit, &view,
+    &prio, &othr, &updn, &conf, &enote, &vnote, &appt, &todo, &eday, &ewek,
+    &togo, &draw, &today, &othr
   };
 
   /* Total length of a command. */
@@ -964,3 +989,20 @@ parse_date (char *date_string, int datefmt, int *year, int *month, int *day)
     *day = lday;
   return (1);
 }
+
+char *
+str_toupper (char *s)
+{
+  int len;
+
+  for (len = 0; s && s[len]; len++)
+    s[len] = toupper (s[len]);
+  return s;
+}
+
+void
+mem_free (void *ptr)
+{
+  if (ptr)
+    free (ptr);
+}
